@@ -11,7 +11,7 @@ use Digest::SHA 'hmac_sha1';
 use MIME::Base64 'encode_base64';
 use URI::Escape 'uri_escape_utf8';
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 has 'ua' => sub {
     my $ua = Mojo::UserAgent->new;
@@ -66,7 +66,8 @@ sub request {
     my $tx = $self->ua->build_tx($method => $url => { Authorization => "OAuth $auth_str" } => @extra );
     $tx = $self->ua->start($tx);
 
-    if ($tx->res->headers->header('X-Rate-Limit-Remaining') < 1) {
+    my $remaing = $tx->res->headers->header('X-Rate-Limit-Remaining');
+    if (defined $remaing and $remaing < 1) {
         my $sleep = $tx->res->headers->header('X-Rate-Limit-Reset') - time();
         sleep $sleep; # wait until limit reset
     }
